@@ -35,9 +35,11 @@ from importlib import import_module
 from pathlib import Path
 from textwrap import indent
 from typing import Tuple
+from zipfile import ZipFile
 
 import click
 import yaml
+from setuptools.dist import Distribution
 
 import kedro
 from kedro.framework.cli.cli import _assert_pkg_name_ok, _handle_exception
@@ -47,6 +49,7 @@ from kedro.framework.cli.utils import (
     _filter_deprecation_warnings,
     call,
     env_option,
+    python_call,
 )
 from kedro.framework.context import KedroContext, load_context
 
@@ -114,7 +117,7 @@ def create_pipeline(name, skip_config, env):
     help="Environment to delete pipeline configuration from. Defaults to `base`."
 )
 @click.option(
-    "-y", "--yes", is_flag=True, help="Confirm deletion of pipeline non-interactively.",
+    "-y", "--yes", is_flag=True, help="Confirm deletion of pipeline non-interactively."
 )
 def delete_pipeline(name, env, yes):
     """Delete a modular pipeline by providing the pipeline name as an argument."""
@@ -185,6 +188,94 @@ def describe_pipeline(name, env):
     click.echo(yaml.dump(result))
 
 
+@pipeline.command("pull")
+@click.argument("package_path", nargs=1)
+@env_option(
+    help="Environment to install the pipeline configuration to. Defaults to `base`."
+)
+@click.option(
+    "--alias",
+    type=str,
+    default="",
+    callback=_check_pipeline_name,
+    help="Alternative name to unpackage under.",
+)
+def pull_package(package_path, env, alias):
+    """Pull a modular pipeline package, unpack it and install the files to corresponding
+    locations.
+    """
+    # pylint: disable=import-outside-toplevel
+    import fsspec
+    from kedro.io.core import get_protocol_and_path
+
+    protocol, _ = get_protocol_and_path(package_path)
+    filesystem = fsspec.filesystem(protocol)
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        temp_dir_path = Path(temp_dir).resolve()
+        if package_path.endswith(".whl") and filesystem.exists(package_path):
+            with filesystem.open(package_path) as fs_file:
+                ZipFile(fs_file).extractall(temp_dir_path)
+        else:
+            python_call(
+                "pip",
+                ["download", "--no-deps", "--dest", str(temp_dir_path), package_path],
+            )
+            wheel_file = list(temp_dir_path.glob("*.whl"))
+            # `--no-deps` should fetch only one wheel file, and CLI should fail if that's
+            # not the case.
+            if len(wheel_file) != 1:
+                file_names = [wf.name for wf in wheel_file]
+                raise KedroCliError(
+                    f"More than 1 or no wheel files found: {str(file_names)}. "
+                    "There has to be exactly one distribution file."
+                )
+            ZipFile(wheel_file[0]).extractall(temp_dir_path)
+
+        dist_info_file = list(temp_dir_path.glob("*.dist-info"))
+        if len(dist_info_file) != 1:
+            raise KedroCliError(
+                f"More than 1 or no dist-info files found from {package_path}. "
+                "There has to be exactly one dist-info directory."
+            )
+        # Extract package name, based on the naming convention for wheel files
+        # https://www.python.org/dev/peps/pep-0427/#file-name-convention
+        package_name = dist_info_file[0].stem.split("-")[0]
+
+        _clean_pycache(temp_dir_path)
+        _install_files(package_name, temp_dir_path, env, alias)
+
+
+def _install_files(
+    package_name: str, source_path: Path, env: str = None, alias: str = None
+):
+    env = env or "base"
+    context = load_context(Path.cwd(), env=env)
+
+    package_source, test_source, conf_source = _get_package_artifacts(
+        source_path, package_name
+    )
+
+    pipeline_name = alias or package_name
+    package_dest, test_dest, conf_dest = _get_pipeline_artifacts(
+        context, pipeline_name=pipeline_name, env=env
+    )
+
+    if conf_source.is_dir():
+        _sync_dirs(conf_source, conf_dest)
+        # `config` was packaged under `package_name` directory with `kedro pipeline package`.
+        # Since `config` was already synced, we don't want to send it again
+        # when syncing the package, so we remove it.
+        shutil.rmtree(str(conf_source))
+
+    if test_source.is_dir():
+        _sync_dirs(test_source, test_dest)
+
+    # Sync everything under package directory, except `config` since we already sent it.
+    if package_source.is_dir():
+        _sync_dirs(package_source, package_dest)
+
+
 @pipeline.command("package")
 @env_option(
     help="Environment where the pipeline configuration lives. Defaults to `base`."
@@ -194,22 +285,35 @@ def describe_pipeline(name, env):
     type=str,
     default="",
     callback=_check_pipeline_name,
-    help="Alternative name to package under",
+    help="Alternative name to package under.",
 )
 @click.option(
     "-d",
     "--destination",
     type=click.Path(resolve_path=True, file_okay=False),
-    help="Location where to create the wheel file. Defaults to `src/dist`",
+    help="Location where to create the wheel file. Defaults to `src/dist`.",
+)
+@click.option(
+    "-v",
+    "--version",
+    type=str,
+    default="0.1",
+    show_default=True,
+    help="Version to package under.",
 )
 @click.argument("name", nargs=1)
-def package_pipeline(name, env, alias, destination):
+def package_pipeline(name, env, alias, destination, version):
     """Package up a pipeline for easy distribution. A .whl file
     will be created in a `<source_dir>/dist/`."""
     context = load_context(Path.cwd(), env=env)
 
     result_path = _package_pipeline(
-        name, context, package_name=alias, destination=destination, env=env
+        name,
+        context,
+        package_name=alias,
+        destination=destination,
+        env=env,
+        version=version,
     )
 
     as_alias = f" as `{alias}`" if alias else ""
@@ -217,25 +321,23 @@ def package_pipeline(name, env, alias, destination):
     click.secho(message, fg="green")
 
 
-def _package_pipeline(
+def _package_pipeline(  # pylint: disable=too-many-arguments
     name: str,
     context: KedroContext,
     package_name: str = None,
     destination: str = None,
     env: str = None,
+    version: str = None,
 ) -> Path:
     package_dir = _get_project_package_dir(context)
     env = env or "base"
     package_name = package_name or name
+    version = version or "0.1"
 
-    # Artifacts to package
-    source_paths = _get_pipeline_artifacts(context, pipeline_name=name, env=env)
-
+    artifacts_to_package = _get_pipeline_artifacts(context, pipeline_name=name, env=env)
     destination = Path(destination) if destination else package_dir.parent / "dist"
-    package_file = destination / f"{package_name}-0.1-py3-none-any.whl"
-    if package_file.is_file():
-        click.secho(f"Package file {package_file} will be overwritten!", fg="yellow")
-    _generate_wheel_file(package_name, destination, source_paths)
+
+    _generate_wheel_file(package_name, destination, artifacts_to_package, version)
 
     _clean_pycache(package_dir)
     _clean_pycache(context.project_path)
@@ -243,39 +345,39 @@ def _package_pipeline(
     return destination
 
 
+def _get_wheel_name(**kwargs):
+    # https://stackoverflow.com/questions/51939257/how-do-you-get-the-filename-of-a-python-wheel-when-running-setup-py
+    dist = Distribution(attrs=kwargs)
+    bdist_wheel_cmd = dist.get_command_obj("bdist_wheel")
+    bdist_wheel_cmd.ensure_finalized()
+
+    distname = bdist_wheel_cmd.wheel_dist_name
+    tag = "-".join(bdist_wheel_cmd.get_tag())
+    return f"{distname}-{tag}.whl"
+
+
 def _generate_wheel_file(
-    package_name: str, destination: Path, source_paths: Tuple[Path, ...]
+    package_name: str, destination: Path, source_paths: Tuple[Path, ...], version: str
 ) -> None:
     with tempfile.TemporaryDirectory() as temp_dir:
         temp_dir_path = Path(temp_dir).resolve()
 
         # Copy source folders
-        target_paths = (
-            temp_dir_path / package_name,
-            temp_dir_path / "tests",
-            # package_data (non-python files) needs to live inside one of the packages
-            temp_dir_path / package_name / "config",
-        )
+        target_paths = _get_package_artifacts(temp_dir_path, package_name)
         for source, target in zip(source_paths, target_paths):
             if source.is_dir():
                 _sync_dirs(source, target)
 
         # Build a setup.py on the fly
-        setup_file = temp_dir_path / "setup.py"
-        package_data = {
-            package_name: [
-                "README.md",
-                "config/parameters*",
-                "config/**/parameters*",
-                "config/parameters*/**",
-            ]
-        }
-        setup_file_context = dict(
-            name=package_name, version="0.1", package_data=json.dumps(package_data)
-        )
-        setup_file.write_text(_SETUP_PY_TEMPLATE.format(**setup_file_context))
+        setup_file = _generate_setup_file(package_name, version, temp_dir_path)
 
-        # python setup.py bdist_wheel --dist-dir src/dist
+        package_file = destination / _get_wheel_name(name=package_name, version=version)
+        if package_file.is_file():
+            click.secho(
+                f"Package file {package_file} will be overwritten!", fg="yellow"
+            )
+
+        # python setup.py bdist_wheel --dist-dir <destination>
         call(
             [
                 sys.executable,
@@ -288,6 +390,23 @@ def _generate_wheel_file(
         )
 
 
+def _generate_setup_file(package_name: str, version: str, output_dir: Path) -> Path:
+    setup_file = output_dir / "setup.py"
+    package_data = {
+        package_name: [
+            "README.md",
+            "config/parameters*",
+            "config/**/parameters*",
+            "config/parameters*/**",
+        ]
+    }
+    setup_file_context = dict(
+        name=package_name, version=version, package_data=json.dumps(package_data)
+    )
+    setup_file.write_text(_SETUP_PY_TEMPLATE.format(**setup_file_context))
+    return setup_file
+
+
 def _create_pipeline(name: str, kedro_version: str, output_dir: Path) -> Path:
     with _filter_deprecation_warnings():
         # pylint: disable=import-outside-toplevel
@@ -374,8 +493,8 @@ def _get_project_package_dir(context: KedroContext) -> Path:
 
 def _get_pipeline_artifacts(
     context: KedroContext, pipeline_name: str, env: str
-) -> Tuple[Path, ...]:
-    """Returns in order: source_path, tests_path, config_path"""
+) -> Tuple[Path, Path, Path]:
+    """From existing project, returns in order: source_path, tests_path, config_path"""
     package_dir = _get_project_package_dir(context)
     artifacts = (
         package_dir / "pipelines" / pipeline_name,
@@ -385,6 +504,19 @@ def _get_pipeline_artifacts(
     return artifacts
 
 
+def _get_package_artifacts(
+    source_path: Path, package_name: str
+) -> Tuple[Path, Path, Path]:
+    """From existing unpacked wheel, returns in order: source_path, tests_path, config_path"""
+    artifacts = (
+        source_path / package_name,
+        source_path / "tests",
+        # package_data (non-python files) needs to live inside one of the packages
+        source_path / package_name / "config",
+    )
+    return artifacts
+
+
 def _copy_pipeline_tests(pipeline_name: str, result_path: Path, package_dir: Path):
     tests_source = result_path / "tests"
     tests_target = package_dir.parent / "tests" / "pipelines" / pipeline_name
