@@ -48,10 +48,13 @@ from kedro.io import DataCatalog
 from kedro.io.core import generate_timestamp
 from kedro.pipeline import Pipeline
 from kedro.pipeline.pipeline import _transcode_split
-from kedro.runner import AbstractRunner, SequentialRunner
+from kedro.runner.runner import AbstractRunner
+from kedro.runner.sequential_runner import SequentialRunner
 from kedro.utils import load_obj
 from kedro.versioning import Journal
 
+_PLUGIN_HOOKS = "kedro.hooks"  # entry-point to load hooks from for installed plugins
+
 
 def _version_mismatch_error(context_version) -> str:
     return (
@@ -249,7 +252,7 @@ class KedroContext(abc.ABC):
         self._setup_logging()
 
         # setup hooks
-        self._register_hooks()
+        self._register_hooks(auto=True)
 
     @property
     @abc.abstractmethod
@@ -310,10 +313,36 @@ class KedroContext(abc.ABC):
         """
         return self._get_pipelines()
 
-    def _register_hooks(self) -> None:
-        """Register all hooks as specified in ``hooks`` with the global ``hook_manager``.
+    def _register_hooks_setuptools(self):
+        """Register pluggy hooks from setuptools entrypoints."""
+        already_registered = self._hook_manager.get_plugins()
+        found = self._hook_manager.load_setuptools_entrypoints(_PLUGIN_HOOKS)
+
+        if found:
+            plugininfo = self._hook_manager.list_plugin_distinfo()
+            plugin_names = sorted(
+                f"{dist.project_name}-{dist.version}"
+                for plugin, dist in plugininfo
+                if plugin not in already_registered
+            )
+            logging.info(
+                "Registered hooks from %d installed plugin(s): %s",
+                found,
+                ", ".join(plugin_names),
+            )
+
+    def _register_hooks(self, auto: bool = False) -> None:
+        """Register all hooks as specified in ``hooks`` with the global ``hook_manager``,
+        and, optionally, from installed plugins.
+
+        Args:
+            auto: An optional flag to enable auto-discovery and registration of plugin hooks.
         """
         self._hook_manager = get_hook_manager()
+
+        if auto:
+            self._register_hooks_setuptools()
+
         for hooks_collection in self.hooks:
             # Sometimes users might create more than one context instance, in which case
             # hooks have already been registered, so we perform a simple check here
