@@ -28,6 +28,7 @@
 """``ParallelRunner`` is an ``AbstractRunner`` implementation. It can
 be used to run the ``Pipeline`` in parallel groups formed by toposort.
 """
+import multiprocessing
 import os
 import pickle
 import sys
@@ -36,6 +37,7 @@ from concurrent.futures import FIRST_COMPLETED, ProcessPoolExecutor, wait
 from itertools import chain
 from multiprocessing.managers import BaseProxy, SyncManager  # type: ignore
 from multiprocessing.reduction import ForkingPickler
+from pathlib import Path
 from pickle import PicklingError
 from typing import Any, Iterable, Set
 
@@ -100,6 +102,41 @@ ParallelRunnerManager.register(  # pylint: disable=no-member
 )
 
 
+def _run_node_synchronization(
+    node: Node, catalog: DataCatalog, is_async: bool = False, run_id: str = None
+) -> Node:
+    """Run a single `Node` with inputs from and outputs to the `catalog`.
+    `KedroContext` class is initialized in every subprocess because of Windows
+    (latest OSX with Python 3.8) limitation.
+    Windows has no "fork", so every subprocess is a brand new process created via "spawn",
+    and KedroContext needs to be created in every subprocess in order to make
+    KedroContext logging setup and hook manager work.
+
+    Args:
+        node: The ``Node`` to run.
+        catalog: A ``DataCatalog`` containing the node's inputs and outputs.
+        is_async: If True, the node inputs and outputs are loaded and saved
+            asynchronously with threads. Defaults to False.
+        run_id: The id of the pipeline run.
+
+    Returns:
+        The node argument.
+
+    """
+
+    if multiprocessing.get_start_method() == "spawn":  # type: ignore
+        # pylint: disable=import-outside-toplevel
+        import kedro.framework.context.context as context  # pragma: no cover
+
+        context.load_context(Path.cwd())  # pragma: no cover
+    # The hard-coded current working directory causes
+    # parallel runner to not work in notebook environment,
+    # but we will revisit this when we work on access `project_path`
+    # from within the runner and data in KedroContext
+    # See https://github.com/quantumblacklabs/private-kedro/issues/701.
+    return run_node(node, catalog, is_async, run_id)
+
+
 class ParallelRunner(AbstractRunner):
     """``ParallelRunner`` is an ``AbstractRunner`` implementation. It can
     be used to run the ``Pipeline`` in parallel groups formed by toposort.
@@ -263,7 +300,13 @@ class ParallelRunner(AbstractRunner):
                 todo_nodes -= ready
                 for node in ready:
                     futures.add(
-                        pool.submit(run_node, node, catalog, self._is_async, run_id)
+                        pool.submit(
+                            _run_node_synchronization,
+                            node,
+                            catalog,
+                            self._is_async,
+                            run_id,
+                        )
                     )
                 if not futures:
                     assert not todo_nodes, (todo_nodes, done_nodes, ready, done)
