@@ -4,7 +4,7 @@
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-# http://www.apache.org/licenses/LICENSE-2.0
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
@@ -19,7 +19,7 @@
 # trademarks of QuantumBlack. The License does not grant you any right or
 # license to the QuantumBlack Trademarks. You may not use the QuantumBlack
 # Trademarks or any confusingly similar mark as a trademark for your product,
-#     or use the QuantumBlack Trademarks in any other manner that might cause
+# or use the QuantumBlack Trademarks in any other manner that might cause
 # confusion in the marketplace, including but not limited to in advertising,
 # on websites, or on software.
 #
@@ -31,8 +31,10 @@ implementations.
 
 import logging
 from abc import ABC, abstractmethod
+from concurrent.futures import ALL_COMPLETED, ThreadPoolExecutor, as_completed, wait
 from typing import Any, Dict, Iterable
 
+from kedro.framework.hooks import get_hook_manager
 from kedro.io import AbstractDataSet, DataCatalog
 from kedro.pipeline import Pipeline
 from kedro.pipeline.node import Node
@@ -43,17 +45,30 @@ class AbstractRunner(ABC):
     implementations.
     """
 
+    def __init__(self, is_async: bool = False):
+        """Instantiates the runner classs.
+
+            Args:
+                is_async: If True, the node inputs and outputs are loaded and saved
+                    asynchronously with threads. Defaults to False.
+
+        """
+        self._is_async = is_async
+
     @property
     def _logger(self):
         return logging.getLogger(self.__module__)
 
-    def run(self, pipeline: Pipeline, catalog: DataCatalog) -> Dict[str, Any]:
+    def run(
+        self, pipeline: Pipeline, catalog: DataCatalog, run_id: str = None
+    ) -> Dict[str, Any]:
         """Run the ``Pipeline`` using the ``DataSet``s provided by ``catalog``
         and save results back to the same objects.
 
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
+            run_id: The id of the run.
 
         Raises:
             ValueError: Raised when ``Pipeline`` inputs cannot be satisfied.
@@ -79,7 +94,11 @@ class AbstractRunner(ABC):
         for ds_name in unregistered_ds:
             catalog.add(ds_name, self.create_default_data_set(ds_name))
 
-        self._run(pipeline, catalog)
+        if self._is_async:
+            self._logger.info(
+                "Asynchronous mode is enabled for loading and saving data"
+            )
+        self._run(pipeline, catalog, run_id)
 
         self._logger.info("Pipeline execution completed successfully.")
 
@@ -121,13 +140,16 @@ class AbstractRunner(ABC):
         return self.run(to_rerun, catalog)
 
     @abstractmethod  # pragma: no cover
-    def _run(self, pipeline: Pipeline, catalog: DataCatalog) -> None:
+    def _run(
+        self, pipeline: Pipeline, catalog: DataCatalog, run_id: str = None
+    ) -> None:
         """The abstract interface for running pipelines, assuming that the
         inputs have already been checked and normalized by run().
 
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
+            run_id: The id of the run.
 
         """
         pass
@@ -169,21 +191,105 @@ class AbstractRunner(ABC):
         )
 
 
-def run_node(node: Node, catalog: DataCatalog) -> Node:
+def run_node(
+    node: Node, catalog: DataCatalog, is_async: bool = False, run_id: str = None
+) -> Node:
     """Run a single `Node` with inputs from and outputs to the `catalog`.
 
     Args:
         node: The ``Node`` to run.
         catalog: A ``DataCatalog`` containing the node's inputs and outputs.
+        is_async: If True, the node inputs and outputs are loaded and saved
+            asynchronously with threads. Defaults to False.
+        run_id: The id of the pipeline run
 
     Returns:
         The node argument.
 
     """
-    inputs = {name: catalog.load(name) for name in node.inputs}
-    outputs = node.run(inputs)
-    for name, data in outputs.items():
-        catalog.save(name, data)
+    if is_async:
+        node = _run_node_async(node, catalog, run_id)
+    else:
+        node = _run_node_sequential(node, catalog, run_id)
+
     for name in node.confirms:
         catalog.confirm(name)
     return node
+
+
+def _run_node_sequential(node: Node, catalog: DataCatalog, run_id: str = None) -> Node:
+    inputs = {name: catalog.load(name) for name in node.inputs}
+    hook_manager = get_hook_manager()
+    is_async = False
+    hook_manager.hook.before_node_run(  # pylint: disable=no-member
+        node=node, catalog=catalog, inputs=inputs, is_async=is_async, run_id=run_id
+    )
+    try:
+        outputs = node.run(inputs)
+    except Exception as error:
+        hook_manager.hook.on_node_error(  # pylint: disable=no-member
+            error=error,
+            node=node,
+            catalog=catalog,
+            inputs=inputs,
+            is_async=is_async,
+            run_id=run_id,
+        )
+        raise error
+    hook_manager.hook.after_node_run(  # pylint: disable=no-member
+        node=node,
+        catalog=catalog,
+        inputs=inputs,
+        outputs=outputs,
+        is_async=is_async,
+        run_id=run_id,
+    )
+
+    for name, data in outputs.items():
+        catalog.save(name, data)
+    return node
+
+
+def _run_node_async(node: Node, catalog: DataCatalog, run_id: str = None) -> Node:
+    with ThreadPoolExecutor() as pool:
+        inputs = {
+            name: pool.submit(catalog.load, name) for name in node.inputs
+        }  # Python dict is thread-safe
+        wait(inputs.values(), return_when=ALL_COMPLETED)
+        inputs = {key: value.result() for key, value in inputs.items()}
+        hook_manager = get_hook_manager()
+        is_async = True
+        hook_manager.hook.before_node_run(  # pylint: disable=no-member
+            node=node, catalog=catalog, inputs=inputs, is_async=is_async, run_id=run_id
+        )
+        try:
+            outputs = node.run(inputs)
+        except Exception as error:
+            hook_manager.hook.on_node_error(  # pylint: disable=no-member
+                error=error,
+                node=node,
+                catalog=catalog,
+                inputs=inputs,
+                is_async=is_async,
+                run_id=run_id,
+            )
+            raise error
+        hook_manager.hook.after_node_run(  # pylint: disable=no-member
+            node=node,
+            catalog=catalog,
+            inputs=inputs,
+            outputs=outputs,
+            is_async=is_async,
+            run_id=run_id,
+        )
+
+        save_futures = set()
+
+        for name, data in outputs.items():
+            save_futures.add(pool.submit(catalog.save, name, data))
+
+        for future in as_completed(save_futures):
+            exception = future.exception()
+            if exception:
+                raise exception
+    return node
