@@ -106,7 +106,8 @@ def _git_sha(proj_dir: Union[str, Path] = None) -> Optional[str]:
             ["git", "rev-parse", "--short", "HEAD"], cwd=proj_dir
         )
         return res.decode().strip()
-    except (subprocess.CalledProcessError, FileNotFoundError):
+    # `subprocess.check_output()` raises `NotADirectoryError` on Windows
+    except (subprocess.CalledProcessError, FileNotFoundError, NotADirectoryError):
         logging.getLogger(__name__).warning("Unable to git describe %s", proj_dir)
     return None
 
